pyMez.Code.DataHandlers API documentation
Description: The DataHandlers subpackage is designed to manipulate data, by allowing different data types to be o...

Top

# pyMez.Code.DataHandlers module

The DataHandlers subpackage is designed to manipulate data, by allowing different data types to be opened, created, saved and updated. The subpackage is further divided into modules grouped by a common theme. Classes for data that are already on disk normally follows the following pattern: `instance=ClassName(file_path,**options)`

For Example to open a XML file that you don't know the model, use

`xml=pyMez.Code.DataHandlers.XMLModels.XMLBase('MyXML.xml')'

or

`xml=XMLBase('MyXML.xml')`

All data models normally have save(), str() and if appropriate show() methods.

## Examples

How to open a s2p file

## Import Structure

DataHandlers typically import from Utils but NOT from Analysis, InstrumentControl or FrontEnds

## Help

`pyMez.Code`

Documentation Home | API Documentation Home | Examples | Index

Show source ≡

    """
    The DataHandlers subpackage is designed to manipulate data, by allowing different data types to be opened,
    created, saved and updated. The subpackage is further divided into modules grouped by a common theme. Classes for data
    that are already on disk normally follows the following pattern:
    `instance=ClassName(file_path,**options)`

    For Example to
    open a XML file that you don't know the model, use

    `xml=pyMez.Code.DataHandlers.XMLModels.XMLBase('MyXML.xml')'

    or

    `xml=XMLBase('MyXML.xml')`

    All data models normally have save(), str() and if appropriate show() methods.

    Examples
    --------
    <a href="../../../Examples/How_To_Open_S2p.html"> How to open a s2p file </a>

    Import Structure
    ----------------
    DataHandlers typically import from Utils but __NOT__ from Analysis, InstrumentControl or FrontEnds

    Help
    -----
    <a href="../index.html">`pyMez.Code`</a>
    <div>
    <a href="../../../pyMez_Documentation.html">Documentation Home</a> |
    <a href="../../index.html">API Documentation Home</a> |
    <a href="../../../Examples/html/Examples_Home.html">Examples</a> |
    <a href="../../../Reference_Index.html">Index </a>
    </div>

    """

## Sub-modules

pyMez.Code.DataHandlers.GeneralModels

GeneralModels is a module that contains general data models and functions for handling them. Its key class is AsciiDataTable that is an abstracted model of a data table with a header full of metadata, a column modeled table (like excel or a csv table) and a footer. Made a change 10/19/2018 to Asci...

pyMez.Code.DataHandlers.GraphModels

Graph Models stores sub classes of graphs that define data translations. All edges or the functions that define translations from one format to another are found in `pyMez.Code.DataHandlers.Translations`. Currently, the module networkx is used to display the graph...

pyMez.Code.DataHandlers.HTMLModels

HTMLModels is a module for the creation and manipulation of HTML based models. It provides a model to open, print, add to and convert html to pdf.

## Examples

    >>new_html=HTMLBase(os.path.join(TESTS_DIRECTORY,"One_Port_Sparameter_20160307_001.html"))
    >>print(new_html)

<h...

pyMez.Code.DataHandlers.MUFModels

A module that holds the models associated with the Microwave Uncertainty Framework. Most models are xml based. Has an interface for running .net as scripts

## Examples

    >>vna_uncert=MUFVNAUncert("MyUncertaintyMenu.VNAUncert")
    >>vna_uncert.get_results_directory()

### <a h...

pyMez.Code.DataHandlers.NISTModels

NISTModels is a module to handle data types found at NIST in Boulder, CO

## Examples

    >>test_OnePortDUTModel()

### NISTModels Example

## Requirements

- [sys](https://docs.python.org/2/library/sys.h...

pyMez.Code.DataHandlers.RadiCALModels

Handles the data saved after running Radical to analyze data. The assumed format is .mat V7.3, if saved in the older format, resave by setting preferences in matlab Environment->Preferences->General->MAT-Files->V7.3. This stores the result as an hd5 file with a .mat extension. Previous versions o...

pyMez.Code.DataHandlers.StatistiCALModels

A wrapper for the StatistiCAL com object and some python classes and functions for interacting with it. More information on statistical can be found at http://www.nist.gov/ctl/rf-technology/related-software.cfm

## Help

`pyMez.Code.DataHandlers`

<a hre...

pyMez.Code.DataHandlers.TouchstoneModels

A module dedicated to the manipulation and storage of touchstone files, such as .s2p or .ts files. Touchstone files are normally s-parameter data for multiport VNA's This module handles all SNP's and different formats such as MA, DB, RI. It currently does not support T, Y, and Z transformations. ...

pyMez.Code.DataHandlers.Translations

Translations.py holds stateless functions that map from one form to another. Warning!!! The functions defined in this module break from normal naming practices to better reflect their purpose. A translation from one object or file takes the form UpperCamelCase_to_UpperCamelCase This change is meant ...

pyMez.Code.DataHandlers.XMLModels

XMLModels is dedicated to handling xml based models, requires lxml to be installed. see also `pyMez.Code.DataHandlers.HTMLModels`. XMLModels has components for basic manipulation, the creation of xml measurements, logs, Instrument states, instrument sheets and file ...

pyMez.Code.DataHandlers.ZipModels

ZipModels holds classes and functions for manipulating zip files. A zipped archive is represented by the class ZipArchive, you can open an existing file and extract_all, show the files contained zip_file.files or add files on disk, full directories, or strings as files.

## Examples